==> paraview_5.4.1+dfsg4.orig.tar.xz: paraview-5.4.1+dfsg4/Qt/Components/pqPropertyWidgetInterface.cxx <==
/*=========================================================================

   Program: ParaView
   Module: pqPropertyWidgetInterface.h

   Copyright (c) 2012 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2.

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/
#include "pqPropertyWidgetInterface.h"

//-----------------------------------------------------------------------------
pqPropertyWidgetInterface::~pqPropertyWidgetInterface()
{
}

//-----------------------------------------------------------------------------
pqPropertyWidget* pqPropertyWidgetInterface::createWidgetForProperty(
  vtkSMProxy* proxy, vtkSMProperty* property)
{
  Q_UNUSED(proxy);
  Q_UNUSED(property);
  return 0;
}

//-----------------------------------------------------------------------------
pqPropertyWidget* pqPropertyWidgetInterface::createWidgetForPropertyGroup(
  vtkSMProxy* proxy, vtkSMPropertyGroup* group)
{
  Q_UNUSED(proxy);
  Q_UNUSED(group);
  return 0;
}

//-----------------------------------------------------------------------------
pqPropertyWidgetDecorator* pqPropertyWidgetInterface::createWidgetDecorator(
  const QString& type, vtkPVXMLElement* config, pqPropertyWidget* widget)
{
  Q_UNUSED(type);
  Q_UNUSED(config);
  Q_UNUSED(widget);
  return NULL;
}

==> paraview_5.7.0.orig.tar.xz: paraview-5.7.0/Qt/Components/pqPropertyWidgetInterface.cxx <==
/*=========================================================================

   Program: ParaView
   Module: pqPropertyWidgetInterface.h

   Copyright (c) 2012 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2.

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/
#include "pqPropertyWidgetInterface.h"

//-----------------------------------------------------------------------------
pqPropertyWidgetInterface::~pqPropertyWidgetInterface()
{
}

//-----------------------------------------------------------------------------
pqPropertyWidget* pqPropertyWidgetInterface::createWidgetForProperty(
  vtkSMProxy* proxy, vtkSMProperty* property, QWidget* parentWidget)
{
  Q_UNUSED(proxy);
  Q_UNUSED(property);
  Q_UNUSED(parentWidget);
  return 0;
}

//-----------------------------------------------------------------------------
pqPropertyWidget* pqPropertyWidgetInterface::createWidgetForPropertyGroup(
  vtkSMProxy* proxy, vtkSMPropertyGroup* group, QWidget* parentWidget)
{
  Q_UNUSED(proxy);
  Q_UNUSED(group);
  Q_UNUSED(parentWidget);
  return 0;
}

//-----------------------------------------------------------------------------
pqPropertyWidgetDecorator* pqPropertyWidgetInterface::createWidgetDecorator(
  const QString& type, vtkPVXMLElement* config, pqPropertyWidget* widget)
{
  Q_UNUSED(type);
  Q_UNUSED(config);
  Q_UNUSED(widget);
  return NULL;
}

//-----------------------------------------------------------------------------
void pqPropertyWidgetInterface::createDefaultWidgetDecorators(pqPropertyWidget* widget)
{
  Q_UNUSED(widget);
  return;
}
